@@ -26,7 +26,7 @@ use crate::query_language::BooleanExpression;
 use crate::Channel;
 use crate::IndexFiles;
 
-pub type VectorsReaderPointer = Arc<dyn VectorReader>;
+pub type VectorsReaderPointer = Arc<RwLock<dyn VectorReader>>;
 pub type VectorsWriterPointer = Arc<RwLock<dyn VectorWriter>>;
 pub type ProtosRequest = VectorSearchRequest;
 pub type ProtosResponse = VectorSearchResponse;
@@ -56,17 +56,22 @@ pub trait VectorReader: std::fmt::Debug + Send + Sync {
     fn search(&self, request: &ProtosRequest, context: &VectorsContext) -> NodeResult<ProtosResponse>;
     fn stored_ids(&self) -> NodeResult<Vec<String>>;
     fn count(&self, vectorset: &str) -> NodeResult<usize>;
+
+    fn update(&mut self) -> NodeResult<()>;
 }
 
 pub trait VectorWriter: std::fmt::Debug + Send + Sync {
-    fn merge(&mut self) -> NodeResult<MergeMetrics>;
-    fn set_resource(&mut self, resource: &Resource) -> NodeResult<()>;
-    fn delete_resource(&mut self, resource_id: &ResourceId) -> NodeResult<()>;
-    fn garbage_collection(&mut self) -> NodeResult<()>;
     fn count(&self) -> NodeResult<usize>;
     fn get_segment_ids(&self) -> NodeResult<Vec<String>>;
     fn get_index_files(&self, ignored_segment_ids: &[String]) -> NodeResult<IndexFiles>;
     fn list_vectorsets(&self) -> NodeResult<Vec<String>>;
+
+    fn merge(&mut self) -> NodeResult<MergeMetrics>;
+    fn set_resource(&mut self, resource: &Resource) -> NodeResult<()>;
+    fn delete_resource(&mut self, resource_id: &ResourceId) -> NodeResult<()>;
+    fn garbage_collection(&mut self) -> NodeResult<()>;
+    fn force_garbage_collection(&mut self) -> NodeResult<()>;
     fn remove_vectorset(&mut self, setid: &VectorSetId) -> NodeResult<()>;
     fn add_vectorset(&mut self, setid: &VectorSetId, similarity: VectorSimilarity) -> NodeResult<()>;
+    fn reload(&mut self) -> NodeResult<()>;
 }
