@@ -17,16 +17,14 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
-import os
-import tempfile
 import time
 from typing import AsyncIterable, Optional
 
 import docker  # type: ignore
 import pytest
-from grpc import aio, insecure_channel  # type: ignore
-from grpc_health.v1 import health_pb2_grpc  # type: ignore
-from grpc_health.v1.health_pb2 import HealthCheckRequest  # type: ignore
+from grpc import aio, insecure_channel
+from grpc_health.v1 import health_pb2_grpc
+from grpc_health.v1.health_pb2 import HealthCheckRequest
 from nucliadb_protos.noderesources_pb2 import EmptyQuery, ShardCreated, ShardId
 from nucliadb_protos.nodewriter_pb2 import NewShardRequest
 from nucliadb_protos.nodewriter_pb2_grpc import NodeWriterStub
@@ -47,7 +45,7 @@ from nucliadb_utils.settings import nats_consumer_settings
 from nucliadb_utils.utilities import get_storage, start_nats_manager, stop_nats_manager
 
 images.settings["nucliadb_node_reader"] = {
-    "image": "eu.gcr.io/stashify-218417/node",
+    "image": "europe-west4-docker.pkg.dev/nuclia-internal/nuclia/node",
     "version": "latest",
     "env": {
         "NUCLIADB_DISABLE_ANALYTICS": "True",
@@ -68,7 +66,7 @@ images.settings["nucliadb_node_reader"] = {
 }
 
 images.settings["nucliadb_node_writer"] = {
-    "image": "eu.gcr.io/stashify-218417/node",
+    "image": "europe-west4-docker.pkg.dev/nuclia-internal/nuclia/node",
     "version": "latest",
     "env": {
         "NUCLIADB_DISABLE_ANALYTICS": "True",
@@ -277,14 +275,12 @@ async def worker(
     node_single,
     gcs_storage,
     nats_manager: NatsConnectionManager,
-    data_path: str,
     writer: Writer,
     writer_stub: NodeWriterStub,
     grpc_server,
     listeners,
 ) -> AsyncIterable[Worker]:
     settings.force_host_id = "node1"
-    settings.data_path = data_path
 
     await get_storage(service_name=SERVICE_NAME)
     worker = await start_worker(writer, nats_manager)
@@ -340,18 +336,3 @@ async def bunch_of_shards(
     finally:
         for shard_id in shard_ids:
             await writer_stub.DeleteShard(ShardId(id=shard_id))  # type: ignore
-
-
-@pytest.fixture(scope="function")
-def data_path():
-    with tempfile.TemporaryDirectory() as td:
-        previous = os.environ.get("DATA_PATH")
-        os.environ["DATA_PATH"] = str(td)
-
-        print("DATA_PATH set to:", str(td))
-        yield str(td)
-
-        if previous is None:
-            os.environ.pop("DATA_PATH")
-        else:  # pragma: no cover
-            os.environ["DATA_PATH"] = previous
