@@ -20,11 +20,14 @@
 
 //! Application initialization and finalization utilities
 
+use std::sync::Arc;
+
+use crate::merge::errors::MergerError;
+use crate::merge::{self, MergeScheduler};
+use crate::settings::Settings;
+use crate::shards::providers::shard_cache::ShardWriterCache;
 use nucliadb_core::prelude::*;
 use nucliadb_core::thread::ThreadPoolBuilder;
-use nucliadb_vectors::data_point_provider::Merger as VectorsMerger;
-
-use crate::settings::Settings;
 
 /// Initialize the index node writer. This function must be called before using
 /// a writer
@@ -41,11 +44,24 @@ pub fn initialize_writer(settings: Settings) -> NodeResult<()> {
 
     // We shallow the error if the threadpools were already initialized
     let _ = ThreadPoolBuilder::new().num_threads(settings.num_global_rayon_threads()).build_global();
-    let _ = VectorsMerger::install_global().map(std::thread::spawn);
 
     Ok(())
 }
 
+/// Initialize the global merge scheduler. This function must be called if merge
+/// scheduler should run
+pub fn initialize_merger(shard_cache: Arc<ShardWriterCache>, settings: Settings) -> Result<(), MergerError> {
+    let merger = MergeScheduler::new(shard_cache, settings);
+    let _ = merge::install_global(merger).map(std::thread::spawn)?;
+    Ok(())
+}
+
+/// Finalizes the global merge scheduler. This function should be called before
+/// finishing the process that started the merge
+pub fn finalize_merger() {
+    merge::stop_global_merger();
+}
+
 /// Initialize the index node reader. This function must be called before using
 /// a reader
 pub fn initialize_reader(settings: Settings) {
