@@ -17,24 +17,25 @@
 // You should have received a copy of the GNU Affero General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
-use std::collections::HashMap;
-use std::fmt::Debug;
-use std::time::*;
-
+use crate::query_io;
 use itertools::Itertools;
 use nucliadb_core::prelude::*;
 use nucliadb_core::protos::order_by::{OrderField, OrderType};
 use nucliadb_core::protos::{
-    DocumentItem, DocumentResult, DocumentSearchRequest, DocumentSearchResponse, FacetResult,
-    FacetResults, OrderBy, ResultScore, StreamRequest,
+    DocumentItem, DocumentResult, DocumentSearchResponse, FacetResult, FacetResults, OrderBy, ResultScore,
+    StreamRequest,
 };
 use nucliadb_core::query_planner::{
     FieldDateType, PreFilterRequest, PreFilterResponse, ValidField, ValidFieldCollector,
 };
+use nucliadb_core::texts::*;
 use nucliadb_core::tracing::{self, *};
 use nucliadb_procs::measure;
+use std::collections::HashMap;
+use std::fmt::Debug;
+use std::time::*;
 use tantivy::collector::{Collector, Count, DocSetCollector, FacetCollector, FacetCounts, TopDocs};
-use tantivy::query::{AllQuery, BooleanQuery, Occur, Query, QueryParser, TermQuery};
+use tantivy::query::{AllQuery, BooleanQuery, Occur, Query, QueryParser};
 use tantivy::schema::*;
 use tantivy::{DocAddress, Index, IndexReader, LeasedItem, ReloadPolicy, Searcher};
 
@@ -58,7 +59,14 @@ fn produce_facets(facets: Vec<String>, facets_count: FacetCounts) -> HashMap<Str
         .map(|facet| (&facets_count, facet))
         .map(|(facets_count, facet)| (facet_count(&facet, facets_count), facet))
         .filter(|(r, _)| !r.is_empty())
-        .map(|(facetresults, facet)| (facet, FacetResults { facetresults }))
+        .map(|(facetresults, facet)| {
+            (
+                facet,
+                FacetResults {
+                    facetresults,
+                },
+            )
+        })
         .collect()
 }
 
@@ -81,20 +89,17 @@ pub struct TextReaderService {
 
 impl Debug for TextReaderService {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        f.debug_struct("FieldReaderService")
-            .field("index", &self.index)
-            .field("schema", &self.schema)
-            .finish()
+        f.debug_struct("FieldReaderService").field("index", &self.index).field("schema", &self.schema).finish()
     }
 }
 
 impl FieldReader for TextReaderService {
     #[measure(actor = "texts", metric = "prefilter")]
     #[tracing::instrument(skip_all)]
-    fn pre_filter(&self, request: &PreFilterRequest) -> NodeResult<PreFilterResponse> {
+    fn prefilter(&self, request: &PreFilterRequest) -> NodeResult<PreFilterResponse> {
+        let schema = &self.schema;
         let mut created_queries = Vec::new();
         let mut modified_queries = Vec::new();
-        let mut labels_queries: Vec<Box<dyn Query>> = Vec::new();
 
         for timestamp_query in request.timestamp_filters.iter() {
             let from = timestamp_query.from.as_ref();
@@ -109,36 +114,28 @@ impl FieldReader for TextReaderService {
             }
         }
 
-        for label in request.labels_filters.iter() {
-            let facet = Facet::from_text(label).unwrap();
-            let term = Term::from_facet(self.schema.facets, &facet);
-            let term_query = TermQuery::new(term, IndexRecordOption::Basic);
-            labels_queries.push(Box::new(term_query));
+        let mut subqueries = vec![];
+        if !created_queries.is_empty() {
+            let created_query: Box<dyn Query> = Box::new(BooleanQuery::new(created_queries));
+            subqueries.push(created_query);
+        }
+        if !modified_queries.is_empty() {
+            let modified_query: Box<dyn Query> = Box::new(BooleanQuery::new(modified_queries));
+            subqueries.push(modified_query);
+        }
+        if let Some(formula) = request.formula.as_ref() {
+            let formula_query = query_io::translate_expression(formula, schema);
+            subqueries.push(formula_query);
+        }
+        if subqueries.is_empty() {
+            return Ok(PreFilterResponse {
+                valid_fields: ValidFieldCollector::All,
+            });
         }
 
-        let pre_filter_query: Box<dyn Query> = if created_queries.is_empty()
-            && modified_queries.is_empty()
-            && labels_queries.is_empty()
-        {
-            Box::new(AllQuery)
-        } else {
-            let mut subqueries = vec![];
-            if !created_queries.is_empty() {
-                let created_query: Box<dyn Query> = Box::new(BooleanQuery::new(created_queries));
-                subqueries.push(created_query);
-            }
-            if !modified_queries.is_empty() {
-                let modified_query: Box<dyn Query> = Box::new(BooleanQuery::new(modified_queries));
-                subqueries.push(modified_query);
-            }
-            if !labels_queries.is_empty() {
-                let labels_query = Box::new(BooleanQuery::intersection(labels_queries));
-                subqueries.push(labels_query);
-            }
-            Box::new(BooleanQuery::intersection(subqueries))
-        };
+        let prefilter_query: Box<dyn Query> = Box::new(BooleanQuery::intersection(subqueries));
         let searcher = self.reader.searcher();
-        let docs_fulfilled = searcher.search(&pre_filter_query, &DocSetCollector)?;
+        let docs_fulfilled = searcher.search(&prefilter_query, &DocSetCollector)?;
 
         // If none of the fields match the pre-filter, thats all the query planner needs to know.
         if docs_fulfilled.is_empty() {
@@ -210,15 +207,10 @@ impl FieldReader for TextReaderService {
 
         Ok(count)
     }
-}
-
-impl ReaderChild for TextReaderService {
-    type Request = DocumentSearchRequest;
-    type Response = DocumentSearchResponse;
 
     #[measure(actor = "texts", metric = "search")]
     #[tracing::instrument(skip_all)]
-    fn search(&self, request: &Self::Request) -> NodeResult<Self::Response> {
+    fn search(&self, request: &ProtosRequest) -> NodeResult<ProtosResponse> {
         self.do_search(request)
     }
 
@@ -257,15 +249,13 @@ impl TextReaderService {
             OrderType::Desc => |t: u64| t,
             OrderType::Asc => |t: u64| u64::MAX - t,
         };
-        TopDocs::with_limit(limit).and_offset(offset).custom_score(
-            move |segment_reader: &SegmentReader| {
-                let reader = match order.sort_by() {
-                    OrderField::Created => segment_reader.fast_fields().date(created).unwrap(),
-                    OrderField::Modified => segment_reader.fast_fields().date(modified).unwrap(),
-                };
-                move |doc: DocId| sorter(reader.get(doc).to_u64())
-            },
-        )
+        TopDocs::with_limit(limit).and_offset(offset).custom_score(move |segment_reader: &SegmentReader| {
+            let reader = match order.sort_by() {
+                OrderField::Created => segment_reader.fast_fields().date(created).unwrap(),
+                OrderField::Modified => segment_reader.fast_fields().date(modified).unwrap(),
+            };
+            move |doc: DocId| sorter(reader.get(doc).to_u64())
+        })
     }
 
     #[tracing::instrument(skip_all)]
@@ -276,10 +266,7 @@ impl TextReaderService {
         let field_schema = TextSchema::new();
         let index = Index::open_in_dir(&config.path)?;
 
-        let reader = index
-            .reader_builder()
-            .reload_policy(ReloadPolicy::OnCommit)
-            .try_into()?;
+        let reader = index.reader_builder().reload_policy(ReloadPolicy::OnCommit).try_into()?;
 
         Ok(TextReaderService {
             index,
@@ -288,11 +275,7 @@ impl TextReaderService {
         })
     }
 
-    fn convert_int_order(
-        &self,
-        response: SearchResponse<u64>,
-        searcher: &Searcher,
-    ) -> DocumentSearchResponse {
+    fn convert_int_order(&self, response: SearchResponse<u64>, searcher: &Searcher) -> DocumentSearchResponse {
         let total = response.total as i32;
         let retrieved_results = (response.page_number + 1) * response.results_per_page;
         let next_page = total > retrieved_results;
@@ -349,20 +332,12 @@ impl TextReaderService {
         }
     }
 
-    fn convert_bm25_order(
-        &self,
-        response: SearchResponse<f32>,
-        searcher: &Searcher,
-    ) -> DocumentSearchResponse {
+    fn convert_bm25_order(&self, response: SearchResponse<f32>, searcher: &Searcher) -> DocumentSearchResponse {
         let total = response.total as i32;
         let retrieved_results = (response.page_number + 1) * response.results_per_page;
         let next_page = total > retrieved_results;
         let results_per_page = response.results_per_page as usize;
-        let result_stream = response
-            .top_docs
-            .into_iter()
-            .take(results_per_page)
-            .enumerate();
+        let result_stream = response.top_docs.into_iter().take(results_per_page).enumerate();
 
         let mut results = Vec::with_capacity(results_per_page);
         for (id, (score, doc_address)) in result_stream {
@@ -429,7 +404,7 @@ impl TextReaderService {
     }
 
     #[tracing::instrument(skip_all)]
-    fn do_search(&self, request: &DocumentSearchRequest) -> NodeResult<DocumentSearchResponse> {
+    fn do_search(&self, request: &ProtosRequest) -> NodeResult<ProtosResponse> {
         use crate::search_query::create_query;
         let id = Some(&request.id);
         let time = Instant::now();
@@ -443,23 +418,17 @@ impl TextReaderService {
             query_parser
         };
         let text = TextReaderService::adapt_text(&query_parser, &request.body);
-        let advanced_query = request
-            .advanced_query
-            .as_ref()
-            .map(|query| query_parser.parse_query(query))
-            .transpose()?;
-        let query = create_query(&query_parser, request, &self.schema, &text, advanced_query);
+        let advanced_query =
+            request.advanced_query.as_ref().map(|query| query_parser.parse_query(query)).transpose()?;
+        let query = create_query(&query_parser, request, &self.schema, &text, advanced_query)?;
 
         // Offset to search from
         let results = request.result_per_page as usize;
         let offset = results * request.page_number as usize;
         let extra_result = results + 1;
         let maybe_order = request.order.clone();
-        let valid_facet_iter = request.faceted.iter().flat_map(|v| {
-            v.labels
-                .iter()
-                .filter(|s| TextReaderService::is_valid_facet(s))
-        });
+        let valid_facet_iter =
+            request.faceted.iter().flat_map(|v| v.labels.iter().filter(|s| TextReaderService::is_valid_facet(s)));
 
         let mut facets = vec![];
         let mut facet_collector = FacetCollector::for_field(self.schema.facets);
