@@ -249,26 +249,13 @@ impl State {
         self.delete_log.prune(age_cap);
         self.no_nodes = number_of_nodes;
         self.work_stack = work_stack;
+        self.current = WorkUnit::new();
     }
 
-    pub fn replace_work_unit(&mut self, journal: Journal) {
-        let Some(unit) = self.work_stack.pop_back() else {
-            return;
-        };
-        let age_cap = self.work_stack.back().and_then(|v| v.load.last().map(|l| l.time()));
-        if let Some(age_cap) = age_cap {
-            self.delete_log.prune(age_cap);
-        }
-        for dp in unit.load.iter() {
-            // The data_point may be older that the refactor
-            self.data_points.remove(&dp.id());
-            self.no_nodes -= dp.no_nodes();
-        }
-        self.add(journal);
-    }
     pub fn dpid_iter(&self) -> impl Iterator<Item = Journal> + '_ {
         self.data_point_iterator().copied()
     }
+
     pub fn keys(&self, location: &Path) -> VectorR<Vec<String>> {
         let mut keys = vec![];
         for journal in self.data_point_iterator().copied() {
@@ -292,9 +279,6 @@ impl State {
     pub fn work_stack_len(&self) -> usize {
         self.work_stack.len()
     }
-    pub fn current_work_unit(&self) -> Option<&[Journal]> {
-        self.work_stack.back().map(|wu| wu.load.as_slice())
-    }
     pub fn stored_len(&self, location: &Path) -> VectorR<Option<u64>> {
         let Some(journal) = self.data_point_iterator().next() else {
             return Ok(None);
@@ -314,7 +298,6 @@ impl Default for State {
 mod test {
     use std::path::Path;
 
-    use nucliadb_core::Channel;
     use rand::random;
     use uuid::Uuid;
 
@@ -379,7 +362,7 @@ mod test {
                 let vector = (0..self.dimension).map(|_| random::<f32>()).collect::<Vec<_>>();
                 elems.push(Elem::new(key, vector, labels, None));
             }
-            Some(DataPoint::new(self.path, elems, None, Similarity::Cosine, Channel::EXPERIMENTAL).unwrap())
+            Some(DataPoint::new(self.path, elems, None, Similarity::Cosine).unwrap())
         }
     }
 
@@ -399,17 +382,5 @@ mod test {
         assert_eq!(state.no_nodes(), no_nodes);
         assert_eq!(state.work_stack.len(), 1);
         assert_eq!(state.current.size(), 0);
-        let work = state.current_work_unit().unwrap();
-        let work = work.iter().map(|j| (state.delete_log(*j), j.id())).collect::<Vec<_>>();
-        let new = DataPoint::merge(dir.path(), &work, Similarity::Cosine, Channel::EXPERIMENTAL).unwrap();
-        std::mem::drop(work);
-        state.replace_work_unit(new.journal());
-        assert!(state.current_work_unit().is_none());
-        assert_eq!(state.work_stack.len(), 0);
-        assert_eq!(state.current.size(), 1);
-        assert_eq!(state.no_nodes(), no_nodes);
-        assert_eq!(state.work_stack.len(), 0);
-        assert_eq!(state.current.size(), 1);
-        assert_eq!(state.no_nodes(), no_nodes);
     }
 }
